import type { Root } from 'hast';
export declare function getColor(classList: string[]): string | undefined;
export declare type Parsable = [string, string] | {
    lang: string;
    code: string;
};
export interface Parsed<T extends Char = Char, L extends Line = Line> {
    language: string;
    lines: L[];
    chars: T[];
}
export interface Tokenized<T extends Token = Token, L extends Line = Line> {
    language: string;
    lines: L[];
    tokens: T[];
}
export interface Line {
    tags: string[];
    number?: number;
}
export interface Text {
    classList: string[];
    sections: string[];
    color?: string;
    background?: string;
    provinance?: 'create' | 'retain' | 'delete';
}
export interface Char extends Text {
    char: string;
    token: [number, number];
}
export interface Token extends Text {
    token: string;
    prior?: [number, number];
    location: [number, number];
}
export declare function parse(language: string, code: string): Parsed<Char>;
export declare const tagRegex: RegExp;
/**
 * @internal
 * @param input - parsed or parsable variable
 * @returns parsed code
 */
export declare function ensureParsed(input: Parsed | Parsable): Parsed;
export declare function ready(): Promise<{
    flagToScope: (flag: string) => string | undefined;
    scopes: () => string[];
    register: (grammars: import("@wooorm/starry-night/lib").Grammar[]) => Promise<void>;
    highlight: (value: string, scope: string) => Root;
}>;
export declare function toString(code: Parsed<Char> | Parsable): string;
export declare function getSpan(tree: Char[], at: number): string;
/**
 * Removes all code-fns tags.
 *
 * @param code - the parsed or parsable code to clean
 */
export declare function clean(code: Parsed<Char> | Parsable): Parsed<Char>;
